#if 0
#include <qtprivate.h>



int quicktime_init_audio_map(quicktime_audio_map_t *atrack,
                             quicktime_trak_t *trak, int encode,
                             lqt_codec_info_t * info);
int quicktime_init_video_map(quicktime_video_map_t *vtrack,
                             quicktime_trak_t *trak, int encode,
                             lqt_codec_info_t * info);
int quicktime_init_vcodec(quicktime_video_map_t *vtrack, int encode,
                          lqt_codec_info_t * info);
int quicktime_init_acodec(quicktime_audio_map_t *atrack, int encode,
                          lqt_codec_info_t * info);


#endif
